CKEditor5.Cloud (ckeditor5_phoenix v1.21.0)

Represents the Cloud configuration for a CKEditor 5 preset.

Summary

Functions

Merges the current Cloud configuration with the provided overrides.

Parses a map into a Cloud struct. Returns {:ok, %Cloud{}} if valid, {:error, reason} if invalid.

Parses a map into a Cloud struct. Returns %Cloud{} if valid, raises an error if invalid.

s()

Defines the schema for a raw Cloud configuration map.

Types

t()

@type t() :: %CKEditor5.Cloud{
  ckbox: CKEditor5.Cloud.CKBox.t() | nil,
  premium: boolean(),
  translations: [String.t()],
  version: String.t()
}

Functions

merge(cloud, override_struct)

Merges the current Cloud configuration with the provided overrides.

parse(map)

Parses a map into a Cloud struct. Returns {:ok, %Cloud{}} if valid, {:error, reason} if invalid.

parse!(cloud_data)

Parses a map into a Cloud struct. Returns %Cloud{} if valid, raises an error if invalid.

s()

Defines the schema for a raw Cloud configuration map.