CKEditor5.Cloud.AssetPackage (ckeditor5_phoenix v1.16.1)

Represents a single asset package containing JavaScript and CSS assets. This module provides functionality to merge multiple asset packages.

Summary

Functions

Merges the current asset package with another asset package, combining js and css arrays.

Types

css_asset()

@type css_asset() :: binary()

js_asset()

t()

@type t() :: %CKEditor5.Cloud.AssetPackage{css: [css_asset()], js: [js_asset()]}

Functions

merge(asset_package, other_asset_package)

Merges the current asset package with another asset package, combining js and css arrays.