CKEditor5.Components.AssignStyles (ckeditor5_phoenix v1.15.8)

Handles style assignments for the Editor component.

Summary

Functions

Assigns styles to the assigns map based on provided style options.

Functions

assign_styles(assigns, merge_styles)

@spec assign_styles(map(), map()) :: map()

Assigns styles to the assigns map based on provided style options.