CKEditor5.Components.Cloud.Assets (ckeditor5_phoenix v1.21.0)
View SourceA component for rendering all necessary CKEditor 5 assets from the cloud. This includes the import map, stylesheets, and UMD scripts.
It's a convenient way to include all required assets with a single component. This component composes other cloud components to provide a unified interface.
⚠️ Warning
This component can only be used if the preset has the Cloud option enabled, which is not available under the GPL license key. You must specify your own Cloud or use a commercial license to utilize this feature.
Summary
Functions
Renders all the assets by composing individual cloud components.
Functions
Renders all the assets by composing individual cloud components.
Attributes
nonce(:string) - The CSP nonce to use for the script and link tags. Defaults tonil.preset(:string) - The name of the preset to use. Defaults to"default".ckbox(:any) - The CKBox configuration to use. If not provided, thecloud.ckboxwill be used. Defaults tonil.premium(:boolean) - Whether to use the premium features of CKEditor 5. If true, thecloud.premiumwill be used. Defaults tonil.translations(:any) - The languages codes for the editor (e.g., 'en', 'pl', 'de', etc.).If not provided, then thecloud.translationswill be used to load language files. Defaults tonil.