CKEditor5.Components.Cloud.Assigns (ckeditor5_phoenix v1.22.0)

Provides module responsible for creating %Cloud{} structures based on the provided assigns.

Summary

Functions

Builds the cloud configuration based on the provided assigns. It retrieves the preset by name, checks if the cloud configuration is valid, and overrides translations and other cloud settings if necessary.

Normalizes the assigns to create a %Cloud{} structure.

Functions

build_cloud!(assigns)

Builds the cloud configuration based on the provided assigns. It retrieves the preset by name, checks if the cloud configuration is valid, and overrides translations and other cloud settings if necessary.

cloud_build_attrs()

(macro)

Normalizes the assigns to create a %Cloud{} structure.