CKEditor5.Components.Cloud.ModulePreload (ckeditor5_phoenix v1.16.1)

A component for rendering module preload link tags of CKEditor 5 in Phoenix.

⚠️ Warning

Import maps can only be used if the preset has the Cloud option enabled, which is not available under the GPL license key. You must specify your own Cloud or use a commercial license to utilize this feature.

Summary

Functions

Renders module preload link tags for all modules in the import map.

Functions

render(assigns)

Renders module preload link tags for all modules in the import map.

Attributes

  • nonce (:string) - The CSP nonce to use for the script tag. Defaults to nil.
  • preset (:string) - The name of the preset to use. Defaults to "default".
  • ckbox (:any) - The CKBox configuration to use. If not provided, the cloud.ckbox will be used. Defaults to nil.
  • premium (:boolean) - Whether to use the premium features of CKEditor 5. If true, the cloud.premium will be used. Defaults to nil.
  • translations (:any) - The languages codes for the editor (e.g., 'en', 'pl', 'de', etc.).If not provided, then the cloud.translations will be used to load language files. Defaults to nil.