CKEditor5.Components.Editor.Assigns (ckeditor5_phoenix v1.21.0)
View SourceHandles assigns processing for the Editor component.
Summary
Functions
Prepares the assigns for the editor component by processing and validating them.
Handles assigns processing for the Editor component.
Prepares the assigns for the editor component by processing and validating them.