CKEditor5.Components.Editor.AttributeValidator (ckeditor5_phoenix v1.17.0)
View SourceValidates attributes for different editor types in the Editor component.
Summary
Functions
Validates attributes based on the editor type.
Validates attributes for different editor types in the Editor component.
Validates attributes based on the editor type.