CKEditor5.Components.Editor.LanguageHandler (ckeditor5_phoenix v1.16.1)

Provides a list of supported CKEditor 5 language codes and handles language code normalization for CKEditor integration.

Summary

Functions

Assigns the normalized language and content_language to the assigns map. The language is used in UI of the editor, while content language is used for editable content.

Functions

assign_language(assigns)

Assigns the normalized language and content_language to the assigns map. The language is used in UI of the editor, while content language is used for editable content.

If no language is provided, it defaults to "en".