CKEditor5.Components.Editor.PresetHandler (ckeditor5_phoenix v1.16.0)

Handles preset loading and type overriding for the Editor component.

Summary

Functions

Loads the preset configuration from the preset name and applies type or upload overrides if specified.

Functions

process_preset(assigns)

Loads the preset configuration from the preset name and applies type or upload overrides if specified.