CKEditor5.Config (ckeditor5_phoenix v1.22.0)
View SourceProvides access to CKEditor 5 configuration, specifically the presets defined in the application environment. Prefer to not modify values too much, do it in other modules.
Summary
Functions
Returns the raw contexts configuration from the application environment. It's unprocessed raw configuration.
Returns the raw presets configuration from the application environment.
It's unprocessed raw configuration, not merged with defaults.
In order to use processed presets, use CKEditor5.Presets.presets/0 or CKEditor5.Presets.presets_with_default/0.
Returns the uploads configuration from the application environment.
Functions
@spec raw_contexts() :: map()
Returns the raw contexts configuration from the application environment. It's unprocessed raw configuration.
@spec raw_presets() :: map()
Returns the raw presets configuration from the application environment.
It's unprocessed raw configuration, not merged with defaults.
In order to use processed presets, use CKEditor5.Presets.presets/0 or CKEditor5.Presets.presets_with_default/0.
@spec uploads_config() :: map()
Returns the uploads configuration from the application environment.