CKEditor5.Context (ckeditor5_phoenix v1.20.0)

Represents the CKEditor 5 context configuration.

Summary

Functions

Parses a map into a Context struct. Returns {:ok, %Context{}} if valid, {:error, reason} if invalid.

Parses a map into a Context struct. Returns %Context{} if valid, raises an error if invalid.

s()

Defines the schema for a raw Context configuration map.

Types

t()

@type t() :: %CKEditor5.Context{
  config: map(),
  custom_translations: CKEditor5.CustomTranslations.t() | nil,
  watchdog: map()
}

Functions

parse(context)

Parses a map into a Context struct. Returns {:ok, %Context{}} if valid, {:error, reason} if invalid.

parse!(data)

Parses a map into a Context struct. Returns %Context{} if valid, raises an error if invalid.

s()

Defines the schema for a raw Context configuration map.