CKEditor5.Contexts (ckeditor5_phoenix v1.22.0)

Provides predefined configurations (contexts) for CKEditor 5.

Summary

Functions

Returns all available contexts.

Retrieves a context configuration by name.

Retrieves a context configuration by name, raising an exception on failure.

Functions

contexts()

Returns all available contexts.

get(t1)

Retrieves a context configuration by name.

Returns {:ok, context} on success, or {:error, reason} on failure.

get!(context_name)

Retrieves a context configuration by name, raising an exception on failure.