CKEditor5.Installer.NPMRegistry (ckeditor5_phoenix v1.21.0)

Module responsible for interacting with the NPM registry. It fetches and extracts NPM packages to certain locations.

Summary

Functions

install_package(package_name, version, destination, callback \\ fn _ -> :ok end)

Downloads and unpacks an NPM package from the registry.

Arguments

  • package_name - The name of the NPM package.
  • version - The version of the package to install.
  • destination - The destination directory where the package should be installed (e.g., "deps/my_package").
  • callback - A function that takes the path to the extracted package (in tmp) and allows modification before moving to destination.