CKEditor5.Preset (ckeditor5_phoenix v1.16.1)
View SourceRepresents a CKEditor 5 preset configuration.
Summary
Functions
Checks if the preset has a Cloud configuration. Returns true if the cloud field is not nil, false otherwise.
Merges the current preset configuration with the provided overrides.
Sets the type of the preset.
Types
@type t() :: %CKEditor5.Preset{ cloud: CKEditor5.Cloud.t() | nil, config: map(), custom_translations: CKEditor5.CustomTranslations.t() | nil, license: CKEditor5.License.t(), type: atom() }