CKEditor5.Preset.EditorType (ckeditor5_phoenix v1.21.0)
View SourceDefines the available editor types for CKEditor5 presets. This module provides a schema for the editor types and includes a function to validate them.
Summary
Functions
Checks if the given type is a decoupled or multiroot editor, which have external editables.
Checks if the given type is a single editing-like editor. Single editing-like editors are those that allow inline or classic editing modes.
Validates the given editor type against the defined schema.
Returns :ok if the type is valid, or an error tuple if it is not.
Functions
Checks if the given type is a decoupled or multiroot editor, which have external editables.
Checks if the given type is a single editing-like editor. Single editing-like editors are those that allow inline or classic editing modes.
Validates the given editor type against the defined schema.
Returns :ok if the type is valid, or an error tuple if it is not.