CKEditor5.Cloud.AssetPackage (ckeditor5_phoenix v1.21.0)
View SourceRepresents a single asset package containing JavaScript and CSS assets. This module provides functionality to merge multiple asset packages.
Summary
Functions
Merges the current asset package with another asset package, combining js and css arrays.