CKEditor5.Components.AssignStyles (ckeditor5_phoenix v1.20.0)
View SourceHandles style assignments for the Editor component.
Summary
Functions
Assigns styles to the assigns map based on provided style options.
Handles style assignments for the Editor component.
Assigns styles to the assigns map based on provided style options.