CKEditor5.Components.Cloud.Importmap (ckeditor5_phoenix v1.21.0)
View SourceA component for rendering import map script tags of CKEditor 5 in Phoenix.
⚠️ Warning
Import maps can only be used if the preset has the Cloud option enabled, which is not available under the GPL license key. You must specify your own Cloud or use a commercial license to utilize this feature.
Summary
Functions
Generates the import map JSON for a given Cloud struct. It can be used when you use the custom
importmap renderer in your application.
Renders the import map script tag.
Functions
Generates the import map JSON for a given Cloud struct. It can be used when you use the custom
importmap renderer in your application.
Renders the import map script tag.
Attributes
nonce(:string) - The CSP nonce to use for the script tag. Defaults tonil.extra_imports(:map) - Additional imports to include in the import map. Defaults to%{}.preset(:string) - The name of the preset to use. Defaults to"default".ckbox(:any) - The CKBox configuration to use. If not provided, thecloud.ckboxwill be used. Defaults tonil.premium(:boolean) - Whether to use the premium features of CKEditor 5. If true, thecloud.premiumwill be used. Defaults tonil.translations(:any) - The languages codes for the editor (e.g., 'en', 'pl', 'de', etc.).If not provided, then thecloud.translationswill be used to load language files. Defaults tonil.