CKEditor5.Components.Context (ckeditor5_phoenix v1.21.0)
View SourceA component for rendering a CKEditor5 context.
Summary
Functions
Attributes
id(:string) - The ID of the context to be used. Use it later in editor components to specify which context to use.If not specified, then a random ID will be generated.context(:any) (required) - The name or reference of the context to be used.language(:string) - The language code for the editor UI (e.g., 'en', 'pl', 'de', etc.). If not provided, will use the default "en" language. Defaults tonil.content_language(:string) - The content language code for the editor (e.g. 'en', 'pl', 'de', etc.). This is used to set thelangattribute on the editable area. If not provided, it will default to the same value aslanguage. Defaults tonil.- Global attributes are accepted.
Slots
inner_block- Optional content of the context. Every editor instance within block will use this context.