CKEditor5.Components.Editor.LanguageHandler (ckeditor5_phoenix v1.21.0)
View SourceProvides a list of supported CKEditor 5 language codes and handles language code normalization for CKEditor integration.
Summary
Functions
Assigns the normalized language and content_language to the assigns map. The language is used in UI of the editor, while content language is used for editable content.