CKEditor5.Helpers (ckeditor5_phoenix v1.20.0)
View SourceCommon helper functions for CKEditor5 components.
Summary
Functions
Assigns a unique ID if one is not already present in assigns.
Generates a random UUID-based ID only when :id key is missing.
This is an alias for generate_id_if_missing/2 to maintain backward compatibility.
Assigns a unique ID if one is not already present in assigns. Generates a random UUID-based ID only when :id key is missing.
Checks if a given version string is in semantic versioning format (e.g., "1.0.0").
Maps all keys in a map to strings.
Parses a style string into a map.
Serializes a map of styles into a CSS string. Converts a map of styles into a string suitable for inline CSS. Example: %{color: "red", "font-size": "16px"} becomes "color: red; font-size: 16px".
Functions
Assigns a unique ID if one is not already present in assigns.
Generates a random UUID-based ID only when :id key is missing.
This is an alias for generate_id_if_missing/2 to maintain backward compatibility.
Assigns a unique ID if one is not already present in assigns. Generates a random UUID-based ID only when :id key is missing.
Checks if a given version string is in semantic versioning format (e.g., "1.0.0").
Maps all keys in a map to strings.
Parses a style string into a map.
Serializes a map of styles into a CSS string. Converts a map of styles into a string suitable for inline CSS. Example: %{color: "red", "font-size": "16px"} becomes "color: red; font-size: 16px".