CKEditor5.License (ckeditor5_phoenix v1.21.0)
View SourceProvides functionality to manage CKEditor 5 license keys.
Summary
Functions
Returns the default license key from environment variable or "GPL".
Formats the license key for safe display by truncating long keys.
Creates a new GPL license struct. This license is compatible with all distribution channels.
Creates a new License struct with the given license key. Automatically extracts the distribution channel from the license key. Returns {:ok, %License{}} for valid keys or {:error, error} for invalid keys.
Creates a new License struct with the given license key. Raises an error if the key is invalid.
Types
Functions
Returns the default license key from environment variable or "GPL".
Formats the license key for safe display by truncating long keys.
@spec gpl() :: t()
Creates a new GPL license struct. This license is compatible with all distribution channels.
Creates a new License struct with the given license key. Automatically extracts the distribution channel from the license key. Returns {:ok, %License{}} for valid keys or {:error, error} for invalid keys.
Creates a new License struct with the given license key. Raises an error if the key is invalid.